****** Written by Marius Hagen and André Anundsen
****** The code constructs variables to be used in the analysis. Data to be used later are stored at the end of the code.
clear all
cd "$dataPath"
set maxvar 32000

clear
** Reading in zip-code information from Kartverket to later add to data on commercial real estate. 
use postnr
** Keep only Oslo and Akershus
keep if fylke == "Oslo" | fylke == "Akershus"
keep postnr komm poststad bydel kommnr fylke
ren postnr zip_code
bysort zip_code : gen dup = _n
keep if dup == 1
drop dup
save postnr_to_county, replace

** Importing raw data. Dropping some information 

cd "$rawdataPath"
use data_clean, clear
cd "$dataPath"

drop description dum_ok 

** Renaming some variables
ren (ok_ident postalcode zone4 mainarea mainlease rentertype) (renter_name zip_code zone2 size rent dum_private_renter)

replace streetletter = "X" if streetletter == ""

** Identifiers for offices and buildings (note that one building may have 
** several different contracts on different offices)
egen office_id = group(streetname streetnumber streetletter zip_code size)
egen building_id = group(streetname streetnumber streetletter zip_code)

destring zip_code streetnumber county renegotiated, replace 

** Adding in geographical information from Kartverket
merge m:1 zip_code using postnr_to_county 
keep if _merge == 3
drop _merge
drop county streetname streetnumber streetletter komm poststad
ren (fylke) (county)
order renter_name zip_code county size rent AS

** Just re-classifying some renters that were not classified as private or public. Only one where we do not know
drop if dum_private_renter == -1

*** For common cost MISSING set == 0
replace commoncost = . if commoncost == 0

** Generating date variables that we can do calculations on
** Extract year, quarter, month and day from contract start and contract end
drop contractmonthlength 
foreach var in start end {
foreach time in year quarter month day {
g contract_`var'_`time' = `time'(contract`var')
}
}
** Find year-month for which contract starts and ends
g contract_start_year_month = ym(contract_start_year,contract_start_month)
g contract_end_year_month  = ym(contract_end_year,contract_end_month)

** Calculate the length of contracts (both in years and months)
g contract_length_year = contract_end_year - contract_start_year
g contract_length_month =contract_end_year_month - contract_start_year_month + 1

** Extract year, quarter, month and day from contract signature date and date for which it is registered in database 
foreach var in reg sign{
foreach time in year quarter month day {
g contract_`var'_`time' = `time'(`var'date)
}
}
** Converting fra square meters to square feets
g lsize_sqm  = log(size)
g lsize2_sqm = lsize^2
g size_sqm   = size

replace size  = size*10.764
g lsize		  = log(size)
g lsize2      = lsize^2

** Generate logarithm of rent and converting to dollar per square feet 
* with average exchange rate from 2004-2018 
g rent_nok   = rent
g lrent_nok  = log(rent_nok)

replace rent  = rent/(6.66*10.764)
g lrent = log(rent)


** Due to few observations, we only include data from 2004 till 2018
keep if contract_start_year > 2003 & contract_start_year < 2019
save data_construtced, replace
