****** Written by Marius Hagen and André Anundsen
****** The code calculates distance from each building to all major metro stations in Oslo. 
****** Then, it calculates the distance to the closest metro station. 
****** Only include stations where minimum three metro lines stop, further, we include Lysaker and Skøyen as they are important public transportation hubs without a metro station.
****** Longitude and latitude from Wikipedia: GEO URI

clear all
set obs 1
g id_help = 1

g x_ullevall=59.946629
g x_forskningsparken=59.943513
g x_blindern=59.940052
g x_majorstua=59.929904
g x_national=59.915045
g x_stortinget=59.913047
g x_jernbane=59.912116
g x_gronland=59.912912
g x_toyen=59.915214
g x_ensjo=59.913364
g x_helsfyr=59.911514
g x_bryn=59.909169
g x_skoyen=59.922161
g x_lysaker=59.912697

g y_ullevall=10.732226
g y_forskningsparken=10.720425
g y_blindern=10.716262
g y_majorstua=10.714931
g y_national=10.733039
g y_stortinget=10.741469
g y_jernbane=10.751211
g y_gronland=10.759563
g y_toyen=10.77467
g y_ensjo=10.786986
g y_helsfyr=10.80368
g y_bryn=10.811834
g y_skoyen=10.679162
g y_lysaker=10.637341

format x* %16.5f
format y* %16.5f
cd "$dataPath"
save tbaner, replace

**  Keeping only unique addresses (removing duplicates)
use data_construtced, clear
bysort latitude longitude : gen dup = _n
keep if dup == 1
ren dup id_help
keep latitude longitude id_help
format lat* %16.5f 
format lon* %16.5f

*** 1) Estimate distance to all metro stations for all unique addresses
*** 2) Estimate the shortest distance to a metro station. Reported in miles
merge m:1 id_help using tbaner
drop _merge
	foreach var in ulleval forskningsparken blindern majorstua national stortinget jernbane gronland toyen ensjo helsfyr bryn skoyen lysaker {
	geodist latitude longitude  x_`var' y_`var', gen(dist_to_`var')
	replace dist_to_`var' = dist_to_`var'
	}

egen shortest_dist_to_metro	 = rowmin(dist_to_ulleval-dist_to_lysaker)
recast double shortest_dist_to_metro	 
format shortest* %16.2f
format dist_to* %16.2f

g metro_name = ""

	foreach var in ulleval forskningsparken blindern majorstua national stortinget jernbane gronland toyen ensjo helsfyr bryn skoyen lysaker {
	replace metro_name = "`var'" if float(dist_to_`var') == float(shortest_dist_to_metro)
	}

keep lat* lon* metro_name shortest_dist_to_metro
merge 1:m latitude longitude using data_construtced
drop _merge

** Include variable where shortest distance is measured in km
g shortest_dist_to_metro_km = shortest_dist_to_metro*1.609344 

save data_construtced_w_metro_dist, replace
