	/*********************************************************************************************************************************************************************/
	* Written by Marius Hagen and André Anundsen
	* Replication code for project on the office market in Oslo. This code sets directories (figures, tables, codes, data), and replicates all results in the
	* project by calling on different sub-codes. Note: It is sufficient to change directories here in order to reproduce all results, i.e., no changes are needed in
	* the sub-codes. 
	/*********************************************************************************************************************************************************************/
	clear all
	set more off	
	set scheme s1mono, permanently
	
	** Set main paths. NOTE: This needs to be changed in order to replicate results! If folder structure is unchanged, no further changes are needed.
	global main1 "P:/CommRealEstate"
	
	** Settting directories
    global rawdataPath 	  			"D:/Arealstatistikk"
	global dataPath 	  			"$main1/Data"
	global outputTables   			"$main1/Tex/Tables/"
	global outputFigures  			"$main1/Tex/Figures/"
	global codeDataPreparationPath  "$main1/Prog/Codes/Replication codes/Data preparation/"
	global codeResultsPath     	    "$main1/Prog/Codes/Replication codes/Results/"
	global adhocCalculations		"$main1/Tex/Calculations/"

	**********************************************************
	***************** Data preparation ***********************
	**********************************************************

	** Constructing variables to be used in the analysis. Data to be used later are stored at the end of the code.
	** Only include observations from 2004 to 2018 (few observations before 2004)
	do "$codeDataPreparationPath/DataPreparation.do"  

	** Calculating distance from each building to all major metro stations in Oslo. 
	** Then, calculate distance to the closest metro station for each building 
	** Also saving an dataset where the 1st and 99th percentile is removed 
	do "$codeDataPreparationPath/DistanceToClosestMetro.do"  

	** Generating coordinates for Bydels-polygons based on coordinates for zip-code polygons. 
	**These are to be used when visualizing geographical differences in the Oslo market in maps
	do "$codeDataPreparationPath/Bydelsgrenser.do"  
	
	** Generating dataset used in the regression analysis
	do "$codeDataPreparationPath/DistanceToClosestMetro_trunc.do"  
	

	**************************************************************************
	********************** Reproducing various results ***********************
	**************************************************************************
	
	** Generating tables with summary statistics -- for full sample, private renters only and public renters only. 
	do "$codeResultsPath/SummaryStats.do"  

	** Generating some graphs to have a first look at the data (all data from 2004 to 2018)
	do "$codeResultsPath/DescriptiveFigures.do"  

	** Calculating means and medians for different geographical segments. Merging everything into one file for later use. 
	do "$codeResultsPath/MeanMedianPrices.do"  
	
	** Estimating alternative hedonic models and reporting results in a table. 
	** Also backing out indices for differnt geographical segments. Merging everything into one file for later use. 
	do "$codeResultsPath/Hedonic.do"  

	** The code plots median, mean and hedonic indices (normalized to be 1 in 2005q1) 
	** for different geographical segments of the Oslo market. Data truncated. All figures are saved. 
	do "$codeResultsPath/FigsMedianMeanHedonic.do"  

	**  The code estimates alternative hedonic models to explore how important different attributes are in explaining why the hedonic deviates from the mean index. 
	do "$codeResultsPath/AlternativeHedonic.do"  

	*** Comparing hedonic indices with different control variables againts eachother and against the mean index. 
	do "$codeResultsPath/FigsHedonicAlternativesMean.do"

	*** Plotting hedonic indices (normalized to be 1 in 2005q1) for different geographical segments of the Oslo market in same plot.
	do "$codeResultsPath/FigsGeographicDiff.do"

	*** Drawing maps for the (full sample) variation in some variables across different geographical segments of the Oslo market
	do "$codeResultsPath/MapsBydeler.do"
	
	*** Drawing maps for the evolution of different variables over time across different geographical segments of the Oslo market
	do "$codeResultsPath/MapsBydelerTime.do"
	
    *** Tables over evolution in the median and mean of different variables over time across different geographical segments of the Oslo market
	do "$codeResultsPath/BydelMedian.do"
	
	do "$codeResultsPath/BydelMean.do"
	
	*** Indices based on signature dates
	do "$codeResultsPath/HedonicSignDate.do"
	
