****** Written by Marius Hagen and André Anundsen
****** The code estimates alternative hedonic models to explore how important different attributes are in explaining why the hedonic deviates from the mean index. 
****** Indices with and without location effects are stores, so that we can compare them to the mean index. 
clear all
cd "$dataPath"
set maxvar 32000
use data_construtced_w_metro_dist_trunc, clear

** Keeping only contracts for offices in buildings with at least 5 transactions (10th pct)
bysort building_id : gen num_trans = _N
keep if num_trans >= 5

** Extend martix size to be able to add more controls
set matsize 10000
sort contract_start_year

global baseline  			 i.contract_start_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated i.zip_code i.building_id
global wo_bld_fe		     i.contract_start_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated i.zip_code
global wo_zip_fe    		 i.contract_start_quarter_year lsize i.dum_private_renter contract_length_year i.renegotiated 

foreach var in baseline wo_bld_fe wo_zip_fe {
qui reg lrent $`var'
preserve
cd "$dataPath"
matrix b = e(b)'
svmat b
matrix bxi = b`i'["176.contract_start_quarter_year".."235.contract_start_quarter_year",1]
svmat bxi
gen rent_index_`var'_all  = exp(bxi)
keep rent_index_`var'_all
drop if rent_index_`var'_all == .
gen dup = _n 
gen contract_start_quarter_year = 176
replace contract_start_quarter_year = contract_start_quarter_year + dup - 1 if dup > 1
tsset contract_start_quarter_year
format contract_start_quarter_year %tq
drop dup
tssmooth ma ma_rent_index_`var'_all = rent_index_`var'_all, window(3 1 0)
save hedonic_`var'_all, replace
restore
}

cd "$dataPath"
clear all
use hedonic_baseline_all
foreach var in wo_bld_fe wo_zip_fe {
merge 1:1 contract_start_quarter_year using hedonic_`var'_all
drop _merge
}
save hedonic_alternatives, replace

