****** Written by Marius Hagen and André Anundsen
****** The code generates some graphs to have a first look at the data  (histograms of contract length, evolution of prices at different percentiles, etc.) 
clear all
cd "$dataPath"
set maxvar 32000
use data_construtced, clear

label var contract_length_year "Contract length (years)"
label var contract_start_year "Contract start year"

*********************************************************
******* Making some histograms on contract length *******
*********************************************************
cd "$outputFigures"
*** Unwegihted histogram of contract length , full sample ***
catplot contract_length_year if contract_length_year < 16, frac recast(bar) bar(1, blcolor(gs8) bfcolor(gs14))  ytitle("Frac. of contracts") yscale(r(0,0.3))  yla(0(0.05)0.3) var1opts(gap(0)) 
graph export histogram_contract_length.pdf, replace
*** Histogram of contract length weighted by office size, full sample ***
catplot contract_length_year [iw=size] if contract_length_year < 16, frac recast(bar) bar(1, blcolor(gs8) bfcolor(gs14))  ytitle("Frac. of contracts") yscale(r(0,0.3))  yla(0(0.05)0.3)  var1opts(gap(0))  
graph export histogram_contract_length_weighted.pdf, replace

forvalues j = 0(1)1 {
*** Unweighted histogram of contract length, public only and private ***
catplot contract_length_year if contract_length_year < 16 & dum_private_renter == `j', frac recast(bar) bar(1, blcolor(gs8) bfcolor(gs14))  ytitle("Frac. of contracts") yscale(r(0,0.3))  yla(0(0.05)0.3)  var1opts(gap(0)) 
graph export histogram_contract_length_type`j'.pdf, replace
*** Histogram of contract length weighted by office size, private and public ***
catplot contract_length_year [iw=size] if contract_length_year < 16 & dum_private_renter == `j', frac recast(bar) bar(1, blcolor(gs8) bfcolor(gs14)) yscale(r(0,0.3))  yla(0(0.05)0.3)   ytitle("Frac. of contracts") var1opts(gap(0))  
graph export histogram_contract_length_weighted_type`j'.pdf, replace
}

** Finding percentiles of rental price distribution in evert year
forvalues i = 25(25)75 {
bysort contract_start_year : egen p`i' = pctile(rent), p(`i')
}
** Grouping into three groups based on rental price distribution
g rent_group = 1
replace rent_group = 2 if rent >= p25 & rent < p75
replace rent_group = 3 if rent > p75 

** Drawing histograms of contract length for the 3 different price categories, full sample and weighing by office size
forvalues i = 1(1)3 {
catplot contract_length_year [iw=size]  if contract_length_year < 16 & rent_group == `i', frac recast(bar) bar(1, blcolor(gs8) bfcolor(gs14)) yscale(r(0,0.3))  yla(0(0.05)0.3)  ytitle("Frac. of contracts") var1opts(gap(0)) 
graph export contract_length_price_cat`i'.pdf, replace
}

** Drawing histograms of contract length for the 3 different price categories, full sample and not weighted by office size
forvalues i = 1(1)3 {
catplot contract_length_year  if contract_length_year < 16 & rent_group == `i', frac recast(bar) bar(1, blcolor(gs8) bfcolor(gs14)) yscale(r(0,0.3))  yla(0(0.05)0.3)  ytitle("Frac. of contracts") var1opts(gap(0)) 
graph export contract_length_price_cat`i'_unweighted.pdf, replace
}


** Drawing histograms of contract length for the 3 different price categories, sub-samples of private and public, weighted by office size
forvalues j = 0(1)1 {
forvalues i = 1(1)3 {
catplot contract_length_year [iw=size]  if contract_length_year < 16 & dum_private_renter == `j' & rent_group == `i', frac recast(bar) bar(1, blcolor(gs8) bfcolor(gs14)) yscale(r(0,0.3))  yla(0(0.05)0.3)  ytitle("Frac. of contracts") var1opts(gap(0)) 
graph export contract_length_type`j'_price_cat`i'.pdf, replace
}
}


*********************************************************************************************************************************************************************************
******* Time series developements of contract length, office size and different parts of the rental price distribution, full sample, private only and public only ***************
*********************************************************************************************************************************************************************************

** Dummies to identify different parts of the town
g all 	  = 1
g private = (dum_private_renter == 1)
g public  = (dum_private_renter == 0)
	
foreach category in all private public {
preserve
keep if `category' == 1
bysort contract_start_year : gen dup = _n 
foreach var in size rent contract_length_year {
foreach i of numlist 10 25 50 75 90 {
bysort contract_start_year : egen `var'_p`i' = pctile(`var'), p(`i')
}
label var `var'_p10   "10 pct."
label var `var'_p25   "25 pct."
label var `var'_p50   "Median"
label var `var'_p75   "75 pct."
label var `var'_p90   "90 pct."

line (`var'_p25 `var'_p50 `var'_p75 ) contract_start_year if dup == 1, lcolor(blue black red) lpattern(dash solid dash) legend(col(3) region(lstyle(none))) xtitle("") xla(2004 2011 2018)
*line (`var'_p10 `var'_p25 `var'_p50 `var'_p75 `var'_p90) contract_start_year if dup == 1, lcolor(red green black blue orange) lpattern(dash dot solid dot dash) legend(cols(5) region(col(white)) )
graph export `var'_over_time_`category'.pdf, replace
drop `var'_p*
}
drop dup
restore
}


*********************************************************************************************************************
******* Time series developments of number of observations ***************
*********************************************************************************************************************

** Contract start year
hist contract_start_year if contract_start_year>2002 & contract_start_year <2019, frequency  xla(2004 2008 2012 2016)  fcolor(gs14) color(gs8) xtitle("Year") ytitle("Number of observations")
graph export observations_over_time_contract_start.pdf, replace

forvalues i = 2004(1) 2018 { 
count if contract_start_year ==`i'
}

** Contract sign year 

* Sample from 2007 (due to few observations earlier) 
* Require tenants to move in at least 30 days after signing contract
g dist = contractstart - signdate
drop if contract_sign_year ==. 
keep if contract_sign_year >= 2007
keep if dist >= 30
hist contract_sign_year if contract_sign_year>2006 & contract_sign_year <2019, frequency  xla(2007 2008 2012 2016)  fcolor(gs14) color(gs8) xtitle("Year") ytitle("Number of observations")
graph export observations_over_time_contract_sign.pdf, replace


*********************************************************************************************************************
** Distribution of distance between signature date and contract start date
*********************************************************************************
** Only include if sign-date is less than 500 days before contract start date
hist dist if dist <500 & dist>30, frac fcolor(gs14) color(gs8) xtitle("Days") ytitle("Frac. of contracts")  xla(100 200 300 400 500)
graph export lag_sign_start_date.pdf, replace

