****** Written by Marius Hagen and André Anundsen
****** The code draw maps for the (full sample) variation in some variables across different geographical segments of the Oslo market
clear all
cd "$dataPath"
set maxvar 32000
use data_construtced, clear
ren zip_code postnr

** Adding identifiers on what part of the town (bydel) we are considering
merge m:1 postnr using Postnummer_info
drop _merge 
sort bydelnr 
g dum_public_renter = 1 - dum_private_renter

**Variables of interest
**Percent of contracts that are private and public in different parts of town
bysort bydelnr : egen perc_private   = mean(100*dum_private_renter) 
bysort bydelnr : egen perc_public    = mean(100*dum_public_renter) 

** Total number of private and public contratcs both across differnt parts of town and in Oslo as a whole
bysort bydelnr : egen tot_private_bydel   = total(dum_private_renter) 
bysort bydelnr : egen tot_public_bydel    = total(dum_public_renter) 
egen tot_private   = total(dum_private_renter) 
egen tot_public    = total(dum_public_renter) 
**Frac of private and public contracts in the different parts of town
g frac_private = 100*(tot_private_bydel/tot_private)
g frac_public = 100*(tot_public_bydel/tot_public)
**Median size and median rent across different parts of town
bysort bydelnr : egen med_rent 		 = median(rent) 
bysort bydelnr : egen med_size 		 = median(size)
*** Total size of all contracts across different parts of Oslo and for the city as a whole
bysort bydelnr : egen tot_size_bydel = total(size)
egen tot_size_all 	 			     = total(size)
** Frac of the total size in the different parts of town
g frac_tot_size 				     = 100*(tot_size_bydel/tot_size_all)
** Help variables to construct size-weighted contract length within different parts of town
g frac_size                          = size/tot_size_bydel
g length_size                        = frac_size*contract_length_year
** Mean contract length across different parts of town, weighted and unweighted
bysort bydelnr : egen mean_length_size_weighted = total(length_size)
bysort bydelnr : egen mean_length			   = mean(contract_length_year)
bysort bydelnr : egen med_length			   = median(contract_length_year)

** Now we have created the variables of interest at the "bydel" level, and we remove duplicates at the zip code level
bysort postnr : gen duplicates = _n
drop if duplicates > 1

sort bydelnr 
keep postnr bydel bydelnr perc_private perc_public med_rent med_size frac_tot_size mean_length_size_weighted mean_length frac_private frac_public med_length
order postnr bydel bydelnr perc_private perc_public med_rent med_size frac_tot_size mean_length_size_weighted mean_length frac_private frac_public med_length
save bydel_data, replace

**Now open our data and draq maps
clear all
cd "$dataPath"
use postnr, replace
merge m:1 postnr using bydel_data
drop _merge 
keep if komm == 301

* Removing Marka and missing bydel
drop if bydelnr == . | bydelnr == 7	 
egen bydelnr2 = group(bydelnr)
drop bydelnr 
ren bydelnr2 bydelnr

bysort bydelnr : g dup = _n
keep if dup ==1
drop dup	

foreach x of varlist perc_private-med_length {
cd "$dataPath"
bysort bydelnr : egen `x'2 = mean(`x')		
bysort postnr : replace `x' = `x'2 if `x' == .	
drop `x'2	
*format `x' %5.0f
}	
*** Map for median size
cd "$dataPath"
local x1 = 0
local x2 = 2499.9
local x3 = 3000
local x4 = 3500
local x5 = 4000
local x6 = 8000
spmap  med_size using koord_bydel , id(bydelnr) fcolor(Blues) clmethod(custom) clbreaks(`x1' `x2' `x3' `x4' `x5' `x6') legend(symy(*1.5) symx(*1.5) size(*2.5))  legorder(hilo)  ///
ocolor(black ..) osize(0.1 ..) legend(position(8))  legend(label(2 "1,300-2,500") label(3 "2,500-3,000") label(4 "3,000-3,500") label(5 "3,500-4,000") label(6 "4,000-5,700"))  
cd "$outputFigures"
graph export map_size.pdf, replace

cd "$dataPath"
local x1 = 0
local x2 = 2499.9
local x3 = 3000
local x4 = 3500
local x5 = 4000
local x6 = 8000
spmap  med_size using koord_bydel , id(bydelnr) fcolor(Blues) clmethod(custom) clbreaks(`x1' `x2' `x3' `x4' `x5' `x6') legend(symy(*1.5) symx(*1.5) size(*2.5))  legorder(hilo)  ///
ocolor(black ..) osize(0.1 ..) legend(position(8))  legend(label(2 "1,300-2,500") label(3 "2,500-3,000") label(4 "3,000-3,500") label(5 "3,500-4,000") label(6 "4,000-5,700")) 


*** Map for fraction of size in different parts of town
cd "$dataPath"
local x1 = 0
local x2 = 0.99
local x3 = 5
local x4 = 10
local x5 = 15
local x6 = 25
spmap  frac_tot_size using koord_bydel , id(bydelnr) fcolor(Blues) clmethod(custom) clbreaks(`x1' `x2' `x3' `x4' `x5' `x6') legend(symy(*1.5) symx(*1.5) size(*2.5))  legorder(hilo)  ///
ocolor(black ..) osize(0.1 ..) legend(position(8)) legend(label(2 "< 1") label(3 "1-5") label(4 "5-10") label(5 "10-15") label(6 "15-20")) 
cd "$outputFigures"
graph export map_frac_tot_size.pdf, replace


*** Overview of the city districts

	clear all
	cd "$dataPath"
	use postnr, replace
	merge m:1 postnr using bydel_data
	drop _merge 
	keep if komm == 301
	bysort bydelnr : g dup = _n
	keep if dup ==1
    
	drop if bydelnr == . | bydelnr == 7	 
	egen bydelnr2 = group(bydelnr)
	drop bydelnr 
	ren bydelnr2 bydelnr
	
			local x1 = 0
			local x2 = 1
			local x3 = 2
			local x4 = 3
			local x5 = 4
			local x6 = 5
			local x7 = 6
			local x8 = 7
			local x9 = 8
			local x10 = 9
			local x11 = 10
			local x12 = 11
			local x13 = 12
			local x14 = 13
			local x15 = 14
			local x16 = 15
			local x17 = 16
			
	spmap  bydelnr  using koord_bydel , id(bydelnr) fcolor(Topological) clmethod(custom) clbreaks(`x1' `x2' `x3' `x4' `x5' `x6' `x7' `x8' `x9' `x10' `x11' `x12' `x13' `x14' `x15' `x16' `x17')  legend(symy(*1.5) symx(*1.5) size(*1.9))  legorder(lohi)  ///
	ocolor(black ..) osize(0.1 ..) legend(label(2 "Alna") label(3 "Bjerke") label(4 "Frogner") label(5 "Gamle Oslo")  label(6 "Grorud" ) label(7 "Grunerløkka" ) label(8 "Nordre Aker" ) label(9 "Nordstrand" ) label(10 "Sagene" ) label(11 "City Centre" ) label(12 "St. Hanshaugen" ) label(13 "Stovner" ) label(14 "Søndre Nordstrand" ) label(15 "Ullern" ) label(16 "Vestre Aker" ) label(17 "Østensjø" )) 
	cd "$outputFigures"
	graph export bydeler.pdf, replace


	

	


