****** Written by Marius Hagen and André Anundsen
****** The code draw maps for the evolution of different variables over time across different geographical segments of the Oslo market

clear all
cd "$dataPath"
set maxvar 32000
** Artificial panel
use data_construtced, clear
ren zip_code postnr
merge m:1 postnr using Postnummer_info
drop _merge 
sort contract_start_year bydelnr 
bysort bydelnr : g dup = _n
keep if dup == 1
ren kommnr komm
keep bydelnr bydel komm
g  contract_start_year  = 2004
expand 15
sort bydelnr 
bysort bydelnr : gen nr = _n
replace contract_start_year  = contract_start_year  + nr - 1
drop nr
save bydel_panel, replace

	use data_construtced, clear
	** Adding identifiers on what part of the town (bydel) we are considering
	ren zip_code postnr
	merge m:1 postnr using Postnummer_info
	drop _merge 
	sort contract_start_year bydelnr 
	**Variables of interest
	**Median size and median rent across different parts of town
	merge m:1 bydelnr contract_start_year using bydel_panel

	g bydel2 = bydel
	replace bydel2 = "Grünerløkka" if bydel == "Sagene"
	replace bydel2 = "Stovner" if bydel == "Grorud"
	replace bydel2 = "Stovner" if bydel == "Alna"
	egen bydelnr2 = group(bydel2)

	bysort bydelnr2 contract_start_year : egen med_rent = median(rent) 
	
	** Now we have created the variables of interest at the "bydel" level, and we remove duplicates at the zip code level
	bysort bydelnr contract_start_year : gen duplicates = _n
	drop if duplicates > 1

drop if contract_start_year == .
replace med_rent = 0 if med_rent == .
order bydel bydelnr  contract_start_year
sort bydelnr 
keep postnr bydel bydelnr komm contract_start_year med_rent 
order postnr bydel bydelnr komm contract_start_year med_rent 
save bydel_data, replace

**Now open our data and draw maps
	clear all
	cd "$dataPath"
	use postnr2, replace
	merge 1:m postnr using bydel_data
	drop _merge 
	keep if komm == 301

	* Removing Marka and missing bydel
	drop if contract_start_year == . 
	replace med_rent = . if med_rent == 0
	replace med_rent = . if bydel == "Nordstrand" | bydel == "Søndre Nordstrand" | bydel == "Vestre Aker"
	
	xtset bydelnr contract_start_year
	g Dmed_rent = 100*(med_rent-l1.med_rent)/l1.med_rent
	order postnr bydel bydelnr komm contract_start_year med_rent Dmed_rent
	drop if bydelnr == . | bydelnr == 7	 
	egen bydelnr2 = group(bydelnr)
	drop bydelnr 
	ren bydelnr2 bydelnr
	drop dup
	bysort bydelnr contract_start_year : g dup = _n
	keep if dup ==1
	drop dup	

	foreach x of varlist med_rent{
*	format `x' %5.0f
		
	egen min= min(`x' )          
	egen max = max(`x' )
	gen interval       = (max - min)/5

	local x1 = min
	local x2 = 15
	local x3 = 22.5
	local x4 = 30
	local x5 = 37.5
	local x6 = max
	
	
	forvalues i = 2004(1)2018 {
	cd "$dataPath"
	spmap  `x' using koord_bydel if contract_start_year == `i', id(bydelnr) ndlabel(No data)  fcolor(Blues) clmethod(custom) clbreaks(`x1' `x2' `x3' `x4' `x5' `x6')    legend(symy(*1.5) symx(*1.5) size(*3.0))  legorder(hilo)  ///
	ocolor(black ..) osize(0.1 ..) legend(position(8)) legend(label(2 "< 15") label(3 "15-22.5") label(4 "22.5-30") label(5 "30-37.5") label(6 "37.5-45")) 
	cd "$outputFigures"
	graph export map_`x'_year_`i'.pdf, replace
	}

	forvalues i = 2004(1)2018 {
	cd "$dataPath"
	spmap  `x' using koord_bydel if contract_start_year == `i', id(bydelnr) ndlabel(For få kontrakter)  fcolor(Blues) clmethod(custom) clbreaks(`x1' `x2' `x3' `x4' `x5' `x6')    legend(symy(*1.5) symx(*1.5) size(*2.5))  legorder(hilo)  ///
	ocolor(black ..) osize(0.1 ..) legend(position(8)) legend(off) 
	cd "$outputFigures"
	graph export map_`x'_year_`i'_no_legend.pdf, replace
	}
drop min max interval
	}


