****** Written by Marius Hagen and André Anundsen
****** The code calculates mean and median rental prices in the office market in Oslo. Results are saved in a table in LaTex format.
****** The code also does these calculations for different geographical segments of the Oslo market
clear all
cd "$dataPath"
set maxvar 32000
use data_construtced_w_metro_dist_trunc, clear

** Keeping only contracts for offices in buildings with at least 5 transactions (10th pct)
bysort building_id : gen num_trans = _N
keep if num_trans >= 5

** Dummies to identify different parts of the town
g all 	  = 1
g ab 	  = (zone1 == "Vika-Aker Brygge")
g fs_u_ab = ((bydel == "Sentrum" | bydel == "Frogner") & zone1 != "Vika-Aker Brygge")
g u_ab    = (bydel != "Sentrum" & bydel != "Frogner")
g vest = 0
replace vest = 1 if bydel == "Frogner" | bydel == "Gamle Oslo" | bydel == "Grünerløkka" | bydel == "Nordre Aker" | bydel == "Sagene" | bydel == "Sentrum" | bydel == "St.Hanshaugen" | bydel == "Ullern" | bydel == "Vestre Aker"
g ost        = 1 - vest
	
** Constructing median and mean rental prices for different sub-markets (parts of the town)
foreach var in all ab fs_u_ab u_ab vest ost {
preserve
keep if `var' == 1
cd "$dataPath"
bysort contract_start_quarter_year : egen mean_rent_`var' = mean(rent)
bysort contract_start_quarter_year : egen median_rent_`var' = median(rent)
bysort contract_start_quarter_year : gen dup = _n 
keep if dup == 1
tsset contract_start_quarter_year
format contract_start_quarter_year %tq
tssmooth ma ma_mean_rent_`var' = mean_rent_`var' , window(3 1 0)
tssmooth ma ma_median_rent_`var' = median_rent_`var' , window(3 1 0)
keep ma_median_rent_`var' ma_mean_rent_`var' contract_start_quarter_year
save MeanMedian_`var', replace
line (ma_mean_rent_`var') contract_start_quarter_year ,xtitle("") ytitle("Mean rent per sq.ft.")
cd "$outputFigures"
graph export Mean_`var'.pdf, replace
line (ma_median_rent_`var') contract_start_quarter_year ,xtitle("") ytitle("Median rent per sq.ft.")
cd "$outputFigures"
graph export Median_`var'.pdf, replace
restore
}

preserve
cd "$dataPath"
clear all
use MeanMedian_all
foreach var in all ab fs_u_ab u_ab vest ost {
merge 1:1 contract_start_quarter_year using MeanMedian_`var'
drop _merge
}
save MeanMedian, replace


