****** Written by Marius Hagen and André Anundsen
****** The code calculates summary statistics for several of the variables included in the dataset. It also segments on private versus publically owned
clear all
cd "$dataPath"
set maxvar 32000
use data_construtced, clear

g brygge  = 100*(zone1 == "Vika-Aker Brygge")
g sentrum = 100*(bydel == "Sentrum" & zone1 != "Vika-Aker Brygge")
g helsfyr = 100*(zone1 == "Helsfyr-Bryn")
g skoyen  = 100*(zone1 == "Skøyen")
g lysaker = 100*(zone1 == "Lysaker")
g nydalen = 100*(zone1 == "Nydalen")
g resten = 100 - brygge - sentrum - helsfyr - skoyen - lysaker - nydalen

replace dum_private_renter = 100*dum_private_renter 
replace AS = 100*AS
replace renegotiated = 100*renegotiated  

g sample_size = 0

** Variables to loop
local vars rent size contract_length_year
local vars2 dum_private_renter renegotiated brygge sentrum helsfyr skoyen lysaker nydalen resten sample_size 

label var brygge  "Vika-Aker Brygge"
label var sentrum "City Centre excl. Vika-Aker Brygge" 
label var helsfyr "Helsfyr-Bryn"
label var skoyen  "Sk{\o}yen"
label var lysaker "Lysaker"
label var nydalen "Nydalen"
label var resten  "Other"
label var sample_size "No. contracts"

label var rent "Rent per sqm. (USD)" 
label var size "Size (sq.ft.)"
label var dum_private_renter "Frac. private"
label var renegotiated "Frac. renegotiated"
label var AS "A/S"
label var contract_length_year "Contract length (years)"

** Dummies to identify different segments
g all = 1
g private = (dum_private_renter == 100)
g public  = (dum_private_renter == 0)

** Producing tables of summary stats and saving in LaTex format
foreach var in all private public {
preserve
keep if `var'== 1
 /* medians */
replace sample_size  = _N
tempname postMeans
tempfile means
postfile `postMeans' ///
str100 Variabel Mean using `means', replace
   
    foreach v of local vars2 {
	local name: variable label `v'
    summarize `v', detail
    local mean = r(mean)
    post `postMeans'  ("`name'") (`mean') 
}
postclose `postMeans'

/* medians */
tempname postSummaryStats
tempfile SummaryStats
postfile `postSummaryStats' ///
   str100 Variabel p10 p25 Mean Median p75 p90 using `SummaryStats', replace
foreach v of local vars {
    local name: variable label `v'
    summarize `v' , detail
    local med = r(p50)
	local mean = r(mean)
	local p10 = r(p10)
	local p25 = r(p25)
	local p75 = r(p75)
	local p90 = r(p90)
	
    post `postSummaryStats' ("`name'") (`p10') (`p25') (`mean') (`med') (`p75') (`p90')
}
postclose `postSummaryStats'

use `SummaryStats', clear
append using `means'
format p10 p25 *Mean *Median p75 p90 %9.3gc
list
cd "$outputTables"
listtab * using "Table_summary_stats_`var'.tex", delim(&) rstyle(tabular)  replace
restore
}




